==> haskell-ghc-typelits-extra-0.3-23-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-ghc-typelits-extra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ghc-typelits-extra
version: 0.3
id: ghc-typelits-extra-0.3-FZ6yqEg4NjTITKJfoDFnFm
key: ghc-typelits-extra-0.3-FZ6yqEg4NjTITKJfoDFnFm
license: BSD-2-Clause
copyright: Copyright © 2015-2016, University of Twente,
           2017-2018, QBayLogic B.V.
maintainer: christiaan.baaij@gmail.com
author: Christiaan Baaij
homepage: http://www.clash-lang.org/
synopsis: Additional type-level operations on GHC.TypeLits.Nat
description:
    Additional type-level operations on @GHC.TypeLits.Nat@:
    .
    * @Max@: type-level <http://hackage.haskell.org/package/base-4.8.2.0/docs/Prelude.html#v:max max>
    .
    * @Min@: type-level <http://hackage.haskell.org/package/base-4.8.2.0/docs/Prelude.html#v:min min>
    .
    * @Div@: type-level <http://hackage.haskell.org/package/base-4.8.2.0/docs/Prelude.html#v:div div>
    .
    * @Mod@: type-level <http://hackage.haskell.org/package/base-4.8.2.0/docs/Prelude.html#v:mod mod>
    .
    * @FLog@: type-level equivalent of <https://hackage.haskell.org/package/integer-gmp/docs/GHC-Integer-Logarithms.html#v:integerLogBase-35- integerLogBase#>
    i.e. the exact integer equivalent to @floor (logBase x y)@
    .
    * @CLog@: type-level equivalent of /the ceiling of/ <https://hackage.haskell.org/package/integer-gmp/docs/GHC-Integer-Logarithms.html#v:integerLogBase-35- integerLogBase#>
    i.e. the exact integer equivalent to @ceiling (logBase x y)@
    .
    * @Log@: type-level equivalent of <https://hackage.haskell.org/package/integer-gmp/docs/GHC-Integer-Logarithms.html#v:integerLogBase-35- integerLogBase#>
    where the operation only reduces when @floor (logBase b x) ~ ceiling (logBase b x)@
    .
    * @GCD@: a type-level <http://hackage.haskell.org/package/base-4.8.2.0/docs/Prelude.html#v:gcd gcd>
    .
    * @LCM@: a type-level <http://hackage.haskell.org/package/base-4.8.2.0/docs/Prelude.html#v:lcm lcm>
    .
    And a custom solver for the above operations defined in
    @GHC.TypeLits.Extra.Solver@ as a GHC type-checker plugin. To use the plugin,
    add the
    .
    @
    OPTIONS_GHC -fplugin GHC.TypeLits.Extra.Solver
    @
    .
    pragma to the header of your file.
category: Type System
abi: ef266aeaf1dae6f176c6a996e983ff1f
exposed: True
exposed-modules:
    GHC.TypeLits.Extra GHC.TypeLits.Extra.Solver
hidden-modules: GHC.TypeLits.Extra.Solver.Unify
                GHC.TypeLits.Extra.Solver.Operations
import-dirs: /usr/lib/ghc-8.6.5/site-local/ghc-typelits-extra-0.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/ghc-typelits-extra-0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/ghc-typelits-extra-0.3
hs-libraries: HSghc-typelits-extra-0.3-FZ6yqEg4NjTITKJfoDFnFm
depends:
    base-4.12.0.0 ghc-8.6.5 ghc-prim-0.5.3
    ghc-tcplugins-extra-0.3-HMKihQacjYaLpepViYwKm7
    ghc-typelits-knownnat-0.6-8RC0WOjd9HzFQuSKu3HQvJ
    ghc-typelits-natnormalise-0.6.2-BUceWyhjOqpGKt4PVeltzF
    integer-gmp-1.0.2.0 transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-ghc-typelits-extra/html/ghc-typelits-extra.haddock
haddock-html: /usr/share/doc/haskell-ghc-typelits-extra/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ghc-typelits-extra-0.3-24-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-ghc-typelits-extra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: ghc-typelits-extra
version: 0.3
id: ghc-typelits-extra-0.3-IEDqKcvmYZZI2sFH9rHf1c
key: ghc-typelits-extra-0.3-IEDqKcvmYZZI2sFH9rHf1c
license: BSD-2-Clause
copyright: Copyright © 2015-2016, University of Twente,
           2017-2018, QBayLogic B.V.
maintainer: christiaan.baaij@gmail.com
author: Christiaan Baaij
homepage: http://www.clash-lang.org/
synopsis: Additional type-level operations on GHC.TypeLits.Nat
description:
    Additional type-level operations on @GHC.TypeLits.Nat@:
    .
    * @Max@: type-level <http://hackage.haskell.org/package/base-4.8.2.0/docs/Prelude.html#v:max max>
    .
    * @Min@: type-level <http://hackage.haskell.org/package/base-4.8.2.0/docs/Prelude.html#v:min min>
    .
    * @Div@: type-level <http://hackage.haskell.org/package/base-4.8.2.0/docs/Prelude.html#v:div div>
    .
    * @Mod@: type-level <http://hackage.haskell.org/package/base-4.8.2.0/docs/Prelude.html#v:mod mod>
    .
    * @FLog@: type-level equivalent of <https://hackage.haskell.org/package/integer-gmp/docs/GHC-Integer-Logarithms.html#v:integerLogBase-35- integerLogBase#>
    i.e. the exact integer equivalent to @floor (logBase x y)@
    .
    * @CLog@: type-level equivalent of /the ceiling of/ <https://hackage.haskell.org/package/integer-gmp/docs/GHC-Integer-Logarithms.html#v:integerLogBase-35- integerLogBase#>
    i.e. the exact integer equivalent to @ceiling (logBase x y)@
    .
    * @Log@: type-level equivalent of <https://hackage.haskell.org/package/integer-gmp/docs/GHC-Integer-Logarithms.html#v:integerLogBase-35- integerLogBase#>
    where the operation only reduces when @floor (logBase b x) ~ ceiling (logBase b x)@
    .
    * @GCD@: a type-level <http://hackage.haskell.org/package/base-4.8.2.0/docs/Prelude.html#v:gcd gcd>
    .
    * @LCM@: a type-level <http://hackage.haskell.org/package/base-4.8.2.0/docs/Prelude.html#v:lcm lcm>
    .
    And a custom solver for the above operations defined in
    @GHC.TypeLits.Extra.Solver@ as a GHC type-checker plugin. To use the plugin,
    add the
    .
    @
    OPTIONS_GHC -fplugin GHC.TypeLits.Extra.Solver
    @
    .
    pragma to the header of your file.
category: Type System
abi: 96886ae90fac116c5af367c164bfbb3f
exposed: True
exposed-modules:
    GHC.TypeLits.Extra GHC.TypeLits.Extra.Solver
hidden-modules: GHC.TypeLits.Extra.Solver.Unify
                GHC.TypeLits.Extra.Solver.Operations
import-dirs: /usr/lib/ghc-8.6.5/site-local/ghc-typelits-extra-0.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/ghc-typelits-extra-0.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/ghc-typelits-extra-0.3
hs-libraries: HSghc-typelits-extra-0.3-IEDqKcvmYZZI2sFH9rHf1c
depends:
    base-4.12.0.0 ghc-8.6.5 ghc-prim-0.5.3
    ghc-tcplugins-extra-0.3-HMKihQacjYaLpepViYwKm7
    ghc-typelits-knownnat-0.6-I0mNvGxRMhQ8mUYT8q8Nmi
    ghc-typelits-natnormalise-0.6.2-4hHNCR3uOWJC6l0fZ8xWZn
    integer-gmp-1.0.2.0 transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-ghc-typelits-extra/html/ghc-typelits-extra.haddock
haddock-html: /usr/share/doc/haskell-ghc-typelits-extra/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
